@@ -1,8 +1,7 @@
 use std::{convert::TryInto, process::Command};
 
 use anyhow::{anyhow, bail};
-use cargo_metadata::camino::Utf8Path;
-use cargo_metadata::Package;
+use cargo_metadata::{camino::Utf8Path, Package};
 use git_repository as git;
 use git_repository::{
     bstr::{BStr, ByteSlice},
@@ -37,8 +36,11 @@ pub fn change_since_last_release(package: &Package, ctx: &crate::Context) -> any
             let current_commit = c?;
             let released_target = tag_ref.peel_to_id_in_place()?;
 
-            // If it's a top-level crate, use the src-directory for now
-            match repo_relative_crate_dir.or_else(|| Some(Utf8Path::new("src"))) {
+            match repo_relative_crate_dir
+                // If it's a top-level crate, use the src-directory for now
+                // KEEP THIS IN SYNC with git::create_ref_history()!
+                .or_else(|| (ctx.meta.workspace_members.len() != 1).then(|| Utf8Path::new("src")))
+            {
                 None => (current_commit != released_target).then(|| PackageChangeKind::ChangedOrNew),
                 Some(dir) => {
                     let components = dir.components().map(component_to_bytes);
